@@ -93,18 +93,24 @@ class DynamicSetting(object):
                    fallback_allowed=obj.get('fallback_allowed', False),
                    download_timeout=obj.get('download_timeout', 1.5))
 
-    def get(self, version=None):
+    def get(self, version=None, verbose=False):
 
         if self.content is None or self.is_fallback:
-            self.load_from_storage(version)
+            if verbose:
+                print(f'{self.slug} - Loading from storage, since content is None or this is the fallback')
+            self.load_from_storage(version, verbose=verbose)
 
         elif self.loaded_version_is_ok(version) and not self.too_old:
+            if verbose:
+                print(f'{self.slug} - Loaded content is ok')
             return self.content
 
         else:
-            self.load_from_storage(version)
+            self.load_from_storage(version, verbose=verbose)
 
         if self.content is None:
+            if verbose:
+                print(f'{self.slug} - Loading fallback')
             self.load_fallback()
 
         return self.content
@@ -120,15 +126,17 @@ class DynamicSetting(object):
         self.load_time = self.current_time
         self.source = source
 
-    def load_from_storage(self, version):
+    def load_from_storage(self, version, verbose=False):
 
-        self.load_from_cache(version)
+        self.load_from_cache(version, verbose=verbose)
 
         if self.content is None or self.too_old:
-            self.download()
+            self.download(verbose=verbose)
 
-    def load_from_cache(self, version):
+    def load_from_cache(self, version, verbose=False):
 
+        if verbose:
+            print(f'{self.slug} - Loading from cache')
         try:
             data = self.redis_client.get_latest_data(
                 keys=[
@@ -141,37 +149,54 @@ class DynamicSetting(object):
             )
             cache_version, download_time, content = self.parse_cache_data(data=data)
             source = 'cache'
+            if verbose:
+                print(f'{self.slug} - Loaded from cache')
         except (redis.connection.ConnectionError, redis.connection.TimeoutError):
-            cache_version, download_time, content = self.load_from_file()
+            if verbose:
+                print(f'{self.slug} - Loading from cache failed')
+            cache_version, download_time, content = self.load_from_file(verbose=verbose)
             source = 'disk'
 
+
         if not content is None:
 
             if self.is_larger_than_loaded_version(cache_version):
+                if verbose:
+                    print(f'{self.slug} - Cache version larger than loaded version')
                 self.load_content(data=content,
                                   version=cache_version,
                                   download_time=download_time,
                                   source=source)
             if self.loaded_version_is_ok(version):
+                if verbose:
+                    print(f'{self.slug} - Loaded version is ok')
                 return
 
-        self.download()
+        self.download(verbose=verbose)
 
-    def load_from_file(self):
+    def load_from_file(self, verbose=False):
 
         self.logger.warning('Loading settings from file')
+        if verbose:
+            print(f'{self.slug} - Loading from disk')
         latest_files = [fn for fn in [self.parse_filename(filename) for filename in os.listdir(self.data_dir)
                                       if filename.endswith('.json') and filename.startswith(self.slug)
                                       and not filename.endswith('fallback.json')] if not fn is None]
         if not latest_files:
+            if verbose:
+                print(f'{self.slug} - No file to load from')
             return None, None, None
 
         latest_file = sorted(latest_files, key=lambda x: int(x['version']))[-1]
         try:
             with open(latest_file['file_path'], 'r') as f:
                 data = json.load(f)
+                if verbose:
+                    print(f'{self.slug} - Loaded from disk')
                 return self.parse_data(data)
         except json.JSONDecodeError:
+            if verbose:
+                print(f'{self.slug} - Invalid file on disk')
             return None, None, None
 
 
@@ -276,9 +301,11 @@ class DynamicSetting(object):
         except (redis.exceptions.TimeoutError, redis.exceptions.ConnectionError):
             return False
 
-    def download(self):
+    def download(self, verbose):
 
         try:
+            if verbose:
+                print(f'{self.slug} - Downloading...')
             r = self.session.get(url=self.url, **self.download_options, timeout=self.download_timeout)
             r.raise_for_status()
         except requests.exceptions.RequestException as e:
@@ -288,15 +315,19 @@ class DynamicSetting(object):
         try:
             data = r.json()
         except json.JSONDecodeError:
-            self.logger('Response from url was no valid json')
+            self.logger.error('Response from url was no valid json')
             return
 
         version, data = self.parse_download_data(data=data)
         if data is None:
+            if verbose:
+                print(f'{self.slug} - Downloaded data invalid')
             return
 
         data = self.validate_download_data(data=data)
         if data is None:
+            if verbose:
+                print(f'{self.slug} - Downloaded data did not validate')
             return
 
         download_time = self.current_time
@@ -304,15 +335,13 @@ class DynamicSetting(object):
             self.write_data_to_redis(data=data, version=version, download_time=download_time)
         except (redis.exceptions.TimeoutError, redis.exceptions.ConnectionError):
             pass
-        
+        self.write_data_to_file(data=data, version=version, download_time=download_time)
+
         self.load_content(data=data,
                           version=version,
                           download_time=download_time,
                           source='download')
 
-        self.write_data_to_file(data=data, version=version, download_time=download_time)
-
-
     def write_data_to_file(self, data, version, download_time):
 
         data = self.build_data_object(content=data, version=version, download_time=download_time)
@@ -355,8 +384,10 @@ class DynamicSetting(object):
             'timestamp': download_time.timestamp()
         }
 
-    def write_data_to_redis(self, data, version, download_time):
+    def write_data_to_redis(self, data, version, download_time, verbose=False):
 
+        if verbose:
+            print(f'{self.slug} - Writing data to redis')
         data = self.build_data_object(content=data, version=version, download_time=download_time)
         result = self.redis_client.set_data_with_version(
             keys=[
@@ -371,9 +402,13 @@ class DynamicSetting(object):
             ]
         )
         if int(result[0]) == 1:
+            if verbose:
+                print(f'{self.slug} - Wrote data to redis successful')
             return
 
         data = result[1]
+        if verbose:
+            print(f'{self.slug} - Version is cache is newer')
         if not data is None:
             cache_version, download_time, content = self.parse_cache_data(data=data)
             if self.is_larger_than_loaded_version(cache_version):
